==> dde-session-shell_6.0.23.tar.xz: BUILD/translations/dde-session-shell_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi_IN">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>गलत कूटशब्द</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>UKey is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your password has expired. Please change it.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChangePasswordWidget</name>
    <message>
        <source>Your password has expired. Please change it and log in again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save</source>
        <translation>संचित करें</translation>
    </message>
    <message>
        <source>Old password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Repeat new password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password hint (Optional)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Passwords do not match</source>
        <translation>कूटशब्द मेल नहीं खाते</translation>
    </message>
    <message>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New password should differ from the current one</source>
        <translation>नया कूटशब्द वर्तमान वाले से अलग होना चाहिए</translation>
    </message>
    <message>
        <source>Password changed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong password</source>
        <translation>गलत कूटशब्द</translation>
    </message>
</context>
<context>
    <name>ControlWidget</name>
    <message>
        <source>Desktop Environment and Display Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keyboard Layout</source>
        <translation>कुंजीपटल अभिन्यास</translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power</source>
        <translation>पॉवर</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>गलत कूटशब्द</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>अंगुली-चिन्ह के सत्यापन का समय समाप्त हो गया है, कृपया मैनुअल रूप से कूटशब्द दर्ज़ करें</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>अंगुली-चिन्ह का मिलान असफल रहा</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PasswordLevelWidget</name>
    <message>
        <source>Weak</source>
        <translation>कमजोर</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>मध्यम</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <source>Password cannot be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must have at least %1 characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must be no more than %1 characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more than %1 palindrome characters please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more than %1 monotonic characters please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more than %1 repeating characters please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not use common words and combinations as password</source>
        <translation>कूटशब्द हेतु साधारण शब्द व संयोजन उपयोग न करें</translation>
    </message>
    <message>
        <source>Create a strong password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>It does not meet password rules</source>
        <translation>यह कूटशब्द नियमानुसार नहीं है</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>बंद करें</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>पुनः आरंभ करें</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>स्थगित करें</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>सुप्त करें</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>लॉक स्क्रीन</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>लॉग आउट</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch user</source>
        <translation>उपयोक्ता बदलें</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>सिस्टम मॉनिटर शुरू करें</translation>
    </message>
</context>
<context>
    <name>UserListPopupWidget</name>
    <message>
        <source>Standard User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Administrator</source>
        <translation>प्रबन्धक</translation>
    </message>
    <message>
        <source>Other Users</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VirtualKeyboardModule</name>
    <message>
        <source>Onboard</source>
        <translation>ऑनबोर्ड</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shut down</source>
        <translation>बंद करें</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>पुनः आरंभ करें</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>स्थगित करें</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>सुप्त करें</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>लॉग आउट</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>ऑन करें</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>ऑफ करें</translation>
    </message>
</context>
</TS>

==> dde-session-shell_6.0.38.tar.xz: BUILD/translations/dde-session-shell_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi_IN">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>गलत कूटशब्द</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>UKey is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>गलत कूटशब्द</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>अंगुली-चिन्ह के सत्यापन का समय समाप्त हो गया है, कृपया मैनुअल रूप से कूटशब्द दर्ज़ करें</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>अंगुली-चिन्ह का मिलान असफल रहा</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>बंद करें</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>पुनः आरंभ करें</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>स्थगित करें</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>सुप्त करें</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>लॉक स्क्रीन</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>लॉग आउट</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>उपयोक्ता बदलें</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>सिस्टम मॉनिटर शुरू करें</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>获取验证码</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Domain Account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shut down</source>
        <translation>बंद करें</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>पुनः आरंभ करें</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>स्थगित करें</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>सुप्त करें</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>लॉग आउट</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>ऑन करें</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>ऑफ करें</translation>
    </message>
</context>
</TS>
